@@ -175,5 +175,5 @@ calc_CommonDose <-  structure(function( # Apply the (un-)logged common age model
     data(ExampleData.DeValues, envir = environment())
     
     ## apply the common dose model
-    calc_CommonDose(ExampleData.DeValues)                         
+    calc_CommonDose(ExampleData.DeValues$CA1)                         
   })
